Exception

Enum Exception 

pub enum Exception {
    IllegalCode,
    IllegalAddress,
    IllegalDataValue,
    ServerFailure,
    Acknowledge,
    ServerBusy,
    GatewayUnavail,
    BadDevice,
    IOError(Error),
    FailedRead,
}
Exception codes explaining possible causes of failure

Variants



IllegalCode

The function code is unknown by the server



IllegalAddress

Dependant on the request



IllegalDataValue

Dependant on the request



ServerFailure

The server failed during the exception



Acknowledge

The server accepted the request, but requires a long time to execute



ServerBusy

The server was unable to accept request



GatewayUnavail

Gateway paths not available



BadDevice

The targeted device failed to respond



IOError(Error)

std::io::Error



FailedRead

Failed to read the necessary bytes for the full transmission or the bytes read are not not in accordance to the Modbus Protocol

Implementations

Source

impl Exception

pub fn code(&self) -> u8

Gives the associated exception code